Subject: [bug#75929] [PATCH v2] services: Use beaconDB as location provider in geoclue.

From: Jonathan Brielmaier <[email-masked]>
Date: Sat, 22 Mar 2025 22:25:47 +0100

The previous used Mozilla Location Service (MLS) was retired in 2024:
https://github.com/mozilla/ichnaea/issues/2065

* gnu/services/desktop.scm (<geoclue-configuration>)
[wifi-geolocation-url]: Switch default provider to beaconDB.
[wifi-submission-url]: Dito.

Change-Id: I95e4600a2d5454bdde4be44b09273694536bd44e
---
 gnu/services/desktop.scm | 7 ++++---
 1 file changed, 4 insertions(+), 3 deletions(-)

diff --git a/gnu/services/desktop.scm b/gnu/services/desktop.scm
index 71d650e14fa..83ea41be48c 100644
--- a/gnu/services/desktop.scm
+++ b/gnu/services/desktop.scm
@@ -19,6 +19,7 @@
 ;;; Copyright © 2023 Zheng Junjie <[email-masked]>
 ;;; Copyright © 2024 45mg <[email-masked]>
 ;;; Copyright © 2024 Raven Hallsby <[email-masked]>
+;;; Copyright © 2025 Jonathan Brielmaier <[email-masked]>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -372,13 +373,13 @@ (define-record-type* <geoclue-configuration>
              (default '()))
   (wifi-geolocation-url
    geoclue-configuration-wifi-geolocation-url
-   ;; Mozilla geolocation service:
-   (default "https://location.services.mozilla.com/v1/geolocate?key=geoclue"))
+   ;; BeaconDB geolocation service:
+   (default "https://api.beacondb.net/v1/geolocate?key=geoclue_guix.gnu.org"))
   (submit-data? geoclue-configuration-submit-data?
                 (default #f))
   (wifi-submission-url
    geoclue-configuration-wifi-submission-url
-   (default "https://location.services.mozilla.com/v1/submit?key=geoclue"))
+   (default "https://api.beacondb.net/v2/geosubmit"))
   (submission-nick geoclue-configuration-submission-nick
                    (default "geoclue"))
   (applications geoclue-configuration-applications

base-commit: 66c44dd6e49b581f33eb98fe764ce75945a0638b
--
2.49.0